@@ -1,6 +1,6 @@
 package Game::Cribbage;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 use Rope;
 use Rope::Autoload;
@@ -189,7 +189,7 @@ sub play_hand {
 
 	chomp($number);
 
-	if ($number eq 'go') {
+	if ($number =~ m/go/i) {
 		my @can = $self->board->cannot_play('player2');
 		if (scalar @can && ref $can[0]) {
 			return;
@@ -297,10 +297,9 @@ sub discard_cards {
 
 	chomp($cards_index);
 
-	my @cards = map { 
+	my @cards = map {
 		$self->board->get_card('player2', $_ - 1);
-	} split " ", $cards_index;
-
+	} grep { $_ =~ m/^\d+$/ && $_ <= 6 } split " ", $cards_index;
 
 	unless (scalar @cards == 2) {
 		$self->discard_cards();
@@ -325,7 +324,7 @@ sub starter {
 	if ($self->dealer) {
 		my $card = $self->board->deck->get(int(rand(39)));	
 		$self->starter_card = $card;
-		$self->add_starter_card('player1', $card);
+		$self->board->add_starter_card('player1', $card);
 		return;
 	}
 
@@ -347,7 +346,7 @@ sub starter {
 
 	my $card = $self->board->deck->get($number);
 	$self->starter_card = $card;
-	my $scored = $self->add_starter_card('player2', $card);
+	my $scored = $self->board->add_starter_card('player2', $card);
 	return;
 }
 
@@ -644,13 +643,15 @@ Game::Cribbage - Cribbage game engine
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
 =head1 SYNOPSIS
 
 	lnation:High lnation$ cribbage
+	
+=for html <img src="/test.png" title="img-tag, local-dist" alt="Inlineimage" />
 
 	...
 
